@@ -16,10 +16,10 @@ int32_t SPVM__Net__SSLeay__HMAC_CTX__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_self = stack[0].oval;
   
-  HMAC_CTX* pointer = env->get_pointer(env, stack, obj_self);
+  HMAC_CTX* self = env->get_pointer(env, stack, obj_self);
   
   if (!env->no_free(env, stack, obj_self)) {
-    HMAC_CTX_free(pointer);
+    HMAC_CTX_free(self);
   }
   
   return 0;
