@@ -20,7 +20,7 @@ Net::SSLeay::OCSP_RESPONSE class in L<SPVM> represents L<OCSP_RESPONSE|https://d
 
 C<method DESTROY : void ();>
 
-Frees native L<OCSP_RESPONSE|https://docs.openssl.org/1.1.1/man3/X509_dup> object by calling native L<OCSP_RESPONSE_free|https://docs.openssl.org/1.1.1/man3/X509_dup> function if C<no_free> flag of the instance is not a true value.
+Calls native L<OCSP_RESPONSE_free|https://docs.openssl.org/1.1.1/man3/X509_dup> function given the pointer value of the instance if C<no_free> flag of the instance is not a true value.
 
 =head1 See Also
 
